@@ -1,4 +1,5 @@
-from typing import Dict, List
+from __future__ import annotations
+
 from urllib.parse import urlparse, urlunparse
 
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
@@ -13,20 +14,22 @@ class GCSLocation(BaseFileLocation):
     location_type = FileLocation.GS
 
     @property
-    def transport_params(self) -> Dict:
+    def hook(self) -> GCSHook:
+        return GCSHook(gcp_conn_id=self.conn_id) if self.conn_id else GCSHook()
+
+    @property
+    def transport_params(self) -> dict:
         """get GCS credentials for storage"""
-        hook = GCSHook(gcp_conn_id=self.conn_id) if self.conn_id else GCSHook()
-        client = hook.get_conn()
+        client = self.hook.get_conn()
         return {"client": client}
 
     @property
-    def paths(self) -> List[str]:
+    def paths(self) -> list[str]:
         """Resolve GS file paths with prefix"""
         url = urlparse(self.path)
         bucket_name = url.netloc
         prefix = url.path[1:]
-        hook = GCSHook(gcp_conn_id=self.conn_id) if self.conn_id else GCSHook()
-        prefixes = hook.list(bucket_name=bucket_name, prefix=prefix)
+        prefixes = self.hook.list(bucket_name=bucket_name, prefix=prefix)
         paths = [
             urlunparse((url.scheme, url.netloc, keys, "", "", "")) for keys in prefixes
         ]
